pub struct AdditionalDetails {
pub _type: Type,
pub detail: String,
pub language_code: Option<String>,
}Expand description
AdditionalDetails : Additional information provided by the selling party for tax-related or any other purpose.
Fields
_type: TypeThe type of the additional information provided by the selling party.
detail: StringThe detail of the additional information provided by the selling party.
language_code: Option<String>The language code of the additional information detail.
Implementations
sourceimpl AdditionalDetails
impl AdditionalDetails
sourcepub fn new(_type: Type, detail: String) -> AdditionalDetails
pub fn new(_type: Type, detail: String) -> AdditionalDetails
Additional information provided by the selling party for tax-related or any other purpose.